@@ -96,7 +96,11 @@ class Scenario:
   def listen(self):
     if not self.init or self.nis:
       raise ScenarioNotStartedException
-    j = Scenario._decode_json(self.srv._waits_for())
+    try:
+      j = Scenario._decode_json(self.srv._waits_for())
+    except UnicodeDecodeError:
+      print('Unicode decode error.')
+      return {}
     if "sfinish" in j:
       if j["sfinish"] is True:
         raise ScenarioTerminatedException
